==> node-typescript_2.5.2.orig.tar.gz: TypeScript-2.5.2/tests/baselines/reference/jsDocTypeTag1.js <==
[
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 26
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 26,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "S",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "string",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 55
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 55,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "N",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "number",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 85
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 85,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "B",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "boolean",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 112
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 112,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "V",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "void",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 144
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 144,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "U",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "undefined",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 171
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 171,
        "length": 2
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Nl",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "null",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 200
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 200,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "A",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        },
        {
          "text": "[",
          "kind": "punctuation"
        },
        {
          "text": "]",
          "kind": "punctuation"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 230
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 230,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "P",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Promise",
          "kind": "interfaceName"
        },
        {
          "text": "<",
          "kind": "punctuation"
        },
        {
          "text": "any",
          "kind": "keyword"
        },
        {
          "text": ">",
          "kind": "punctuation"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 259
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 259,
        "length": 3
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Obj",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 292
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 292,
        "length": 4
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Func",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Function",
          "kind": "localName"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 319
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 319,
        "length": 7
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "AnyType",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 349
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 349,
        "length": 5
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "QType",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 389
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 389,
        "length": 4
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "SOrN",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "string",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "|",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "number",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": []
    }
  }
]

==> node-typescript_2.7.2.orig.tar.gz: TypeScript-2.7.2/tests/baselines/reference/jsDocTypeTag1.js <==
[
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 26
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 26,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "S",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "string",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{String}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 55
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 55,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "N",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "number",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Number}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 85
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 85,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "B",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "boolean",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Boolean}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 112
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 112,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "V",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "void",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Void}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 144
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 144,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "U",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "undefined",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Undefined}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 171
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 171,
        "length": 2
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Nl",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "null",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Null}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 200
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 200,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "A",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        },
        {
          "text": "[",
          "kind": "punctuation"
        },
        {
          "text": "]",
          "kind": "punctuation"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Array}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 230
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 230,
        "length": 1
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "P",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Promise",
          "kind": "interfaceName"
        },
        {
          "text": "<",
          "kind": "punctuation"
        },
        {
          "text": "any",
          "kind": "keyword"
        },
        {
          "text": ">",
          "kind": "punctuation"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Promise}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 259
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 259,
        "length": 3
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Obj",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Object}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 292
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 292,
        "length": 4
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Func",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "Function",
          "kind": "localName"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{Function}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 319
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 319,
        "length": 7
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "AnyType",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{*}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 349
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 349,
        "length": 5
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "QType",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "any",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{?}"
        }
      ]
    }
  },
  {
    "marker": {
      "fileName": "/tests/cases/fourslash/jsDocTypeTag1.js",
      "position": 389
    },
    "quickInfo": {
      "kind": "var",
      "kindModifiers": "",
      "textSpan": {
        "start": 389,
        "length": 4
      },
      "displayParts": [
        {
          "text": "var",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "SOrN",
          "kind": "localName"
        },
        {
          "text": ":",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "string",
          "kind": "keyword"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "|",
          "kind": "punctuation"
        },
        {
          "text": " ",
          "kind": "space"
        },
        {
          "text": "number",
          "kind": "keyword"
        }
      ],
      "documentation": [],
      "tags": [
        {
          "name": "type",
          "text": "{String|Number}"
        }
      ]
    }
  }
]
